# Parameterizations

The pages below provide an overview of the five main supported `qp` parameterizations:

```{toctree}
:titlesonly:

hist.md
interp.md
irregularinterp.md
mixmod.md
quant.md

```

There exist additional parameterizations, however they are in various stages of completeness and are not guaranteed to work with all of the functions described in the documentation. For more information about these parameterizations see the parameterization [API documentation](#qp.parameterizations.hist.hist.hist_gen).

## SciPy parameterizations

`qp` also incorporates all of the continuous distributions from <inv:scipy#scipy.stats> as parameterizations, allowing you to create Ensembles parameterized by these distributions. The main limitations on these parameterizations is that they cannot be converted to, as they have no conversion functions. Additionally, their `create_ensemble()` method takes a data dictionary instead of specific arguments, as shown in the [Cookbook](../cookbook/ensemblemanipulation.md#creating-an-ensemble-from-a-parameterization-inherited-from-scipy).

You can access these parameterizations from the `qp.stats` module, as shown below:

```{doctest}

>>> import qp
>>> ens_n = qp.stats.norm.create_ensemble(dict(loc=np.array([0,1]),scale=np.array([0.25,0.5])))
>>> ens_n
Ensemble(the_class=norm,shape=(2,1))

```

The available parameterizations are listed below, with links to their SciPy documentation for more information.

| Function                                                                                                                                      | Inputs                   | Description                                                                  |
| --------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------ | ---------------------------------------------------------------------------- |
| [alpha](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.alpha.html#scipy.stats.alpha)                                        | a                        | An alpha continuous random variable.                                         |
| [anglit](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.anglit.html#scipy.stats.anglit)                                     | loc, scale               | An anglit continuous random variable.                                        |
| [arcsine](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.arcsine.html#scipy.stats.arcsine)                                  | loc, scale               | An arcsine continuous random variable.                                       |
| [argus](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.argus.html#scipy.stats.argus)                                        | chi, loc, scale          | Argus distribution                                                           |
| [beta](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.beta.html#scipy.stats.beta)                                           | a, b, loc, scale         | A beta continuous random variable.                                           |
| [betaprime](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.betaprime.html#scipy.stats.betaprime)                            | a, b, loc, scale         | A beta prime continuous random variable.                                     |
| [bradford](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.bradford.html#scipy.stats.bradford)                               | c, loc, scale            | A Bradford continuous random variable.                                       |
| [burr](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.burr.html#scipy.stats.burr)                                           | c, d, loc, scale         | A Burr (Type III) continuous random variable.                                |
| [burr12](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.burr12.html#scipy.stats.burr12)                                     | c, d, loc, scale         | A Burr (Type XII) continuous random variable.                                |
| [cauchy](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.cauchy.html#scipy.stats.cauchy)                                     | loc, scale               | A Cauchy continuous random variable.                                         |
| [chi](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.chi.html#scipy.stats.chi)                                              | df, loc, scale           | A chi continuous random variable.                                            |
| [chi2](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.chi2.html#scipy.stats.chi2)                                           | df, loc, scale           | A chi-squared continuous random variable.                                    |
| [cosine](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.cosine.html#scipy.stats.cosine)                                     | loc, scale               | A cosine continuous random variable.                                         |
| [crystalball](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.crystalball.html#scipy.stats.crystalball)                      | beta, m, loc, scale      | Crystalball distribution                                                     |
| [dgamma](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.dgamma.html#scipy.stats.dgamma)                                     | a, loc, scale            | A double gamma continuous random variable.                                   |
| [dpareto_lognorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.dpareto_lognorm.html#scipy.stats.dpareto_lognorm)          | u, s, a, b, loc, scale   | A double Pareto lognormal continuous random variable.                        |
| [dweibull](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.dweibull.html#scipy.stats.dweibull)                               | c, loc, scale            | A double Weibull continuous random variable.                                 |
| [erlang](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.erlang.html#scipy.stats.erlang)                                     | a, loc, scale            | An Erlang continuous random variable.                                        |
| [expon](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.expon.html#scipy.stats.expon)                                        | loc, scale               | An exponential continuous random variable.                                   |
| [exponnorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.exponnorm.html#scipy.stats.exponnorm)                            | K, loc, scale            | An exponentially modified Normal continuous random variable.                 |
| [exponweib](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.exponweib.html#scipy.stats.exponweib)                            | a, c, loc, scale         | An exponentiated Weibull continuous random variable.                         |
| [exponpow](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.exponpow.html#scipy.stats.exponpow)                               | b, loc, scale            | An exponential power continuous random variable.                             |
| [f](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.f.html#scipy.stats.f)                                                    | dfn, dfd, loc, scale     | An F continuous random variable.                                             |
| [fatiguelife](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.fatiguelife.html#scipy.stats.fatiguelife)                      | c, loc, scale            | A fatigue-life (Birnbaum-Saunders) continuous random variable.               |
| [fisk](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.fisk.html#scipy.stats.fisk)                                           | c, loc, scale            | A Fisk continuous random variable.                                           |
| [foldcauchy](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.foldcauchy.html#scipy.stats.foldcauchy)                         | c, loc, scale            | A folded Cauchy continuous random variable.                                  |
| [foldnorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.foldnorm.html#scipy.stats.foldnorm)                               | c, loc, scale            | A folded normal continuous random variable.                                  |
| [genlogistic](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.genlogistic.html#scipy.stats.genlogistic)                      | c, loc, scale            | A generalized logistic continuous random variable.                           |
| [gennorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.gennorm.html#scipy.stats.gennorm)                                  | beta, loc, scale         | A generalized normal continuous random variable.                             |
| [genpareto](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.genpareto.html#scipy.stats.genpareto)                            | c, loc, scale            | A generalized Pareto continuous random variable.                             |
| [genexpon](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.genexpon.html#scipy.stats.genexpon)                               | a, b, c, loc             | A generalized exponential continuous random variable.                        |
| [genextreme](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.genextreme.html#scipy.stats.genextreme)                         | c, loc, scale            | A generalized extreme value continuous random variable.                      |
| [gausshyper](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.gausshyper.html#scipy.stats.gausshyper)                         | a, b,c, z, loc, scale    | A Gauss hypergeometric continuous random variable.                           |
| [gamma](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.gamma.html#scipy.stats.gamma)                                        | a, loc, scale            | A gamma continuous random variable.                                          |
| [gengamma](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.gengamma.html#scipy.stats.gengamma)                               | a, c, loc, scale         | A generalized gamma continuous random variable.                              |
| [genhalflogistic](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.genhalflogistic.html#scipy.stats.genhalflogistic)          | c, loc, scale            | A generalized half-logistic continuous random variable.                      |
| [genhyperbolic](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.genhyperbolic.html#scipy.stats.genhyperbolic)                | p, a, b, loc, scale      | A generalized hyperbolic continuous random variable.                         |
| [geninvgauss](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.geninvgauss.html#scipy.stats.geninvgauss)                      | p, b, loc, scale         | A Generalized Inverse Gaussian continuous random variable.                   |
| [gibrat](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.gibrat.html#scipy.stats.gibrat)                                     | loc, scale               | A Gibrat continuous random variable.                                         |
| [gompertz](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.gompertz.html#scipy.stats.gompertz)                               | c, loc, scale            | A Gompertz (or truncated Gumbel) continuous random variable.                 |
| [gumbel_r](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.gumbel_r.html#scipy.stats.gumbel_r)                               | loc, scale               | A right-skewed Gumbel continuous random variable.                            |
| [gumbel_l](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.gumbel_l.html#scipy.stats.gumbel_l)                               | loc, scale               | A left-skewed Gumbel continuous random variable.                             |
| [halfcauchy](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.halfcauchy.html#scipy.stats.halfcauchy)                         | loc, scale               | A Half-Cauchy continuous random variable.                                    |
| [halflogistic](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.halflogistic.html#scipy.stats.halflogistic)                   | loc, scale               | A half-logistic continuous random variable.                                  |
| [halfnorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.halfnorm.html#scipy.stats.halfnorm)                               | loc, scale               | A half-normal continuous random variable.                                    |
| [halfgennorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.halfgennorm.html#scipy.stats.halfgennorm)                      | beta, loc, scale         | The upper half of a generalized normal continuous random variable.           |
| [hypsecant](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.hypsecant.html#scipy.stats.hypsecant)                            | loc, scale               | A hyperbolic secant continuous random variable.                              |
| [invgamma](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.invgamma.html#scipy.stats.invgamma)                               | a, loc, scale            | An inverted gamma continuous random variable.                                |
| [invgauss](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.invgauss.html#scipy.stats.invgauss)                               | mu, loc, scale           | An inverse Gaussian continuous random variable.                              |
| [invweibull](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.invweibull.html#scipy.stats.invweibull)                         | c, loc, scale            | An inverted Weibull continuous random variable.                              |
| [irwinhall](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.irwinhall.html#scipy.stats.irwinhall)                            | n, loc, scale            | An Irwin-Hall (Uniform Sum) continuous random variable.                      |
| [jf_skew_t](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.jf_skew_t.html#scipy.stats.jf_skew_t)                            | a, b, loc, scale         | Jones and Faddy skew-t distribution.                                         |
| [johnsonsb](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.johnsonsb.html#scipy.stats.johnsonsb)                            | a, b, loc, scale         | A Johnson SB continuous random variable.                                     |
| [johnsonsu](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.johnsonsu.html#scipy.stats.johnsonsu)                            | a, b, loc, scale         | A Johnson SU continuous random variable.                                     |
| [kappa4](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.kappa4.html#scipy.stats.kappa4)                                     | h, k, loc, scale         | Kappa 4 parameter distribution.                                              |
| [kappa3](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.kappa3.html#scipy.stats.kappa3)                                     | a, loc, scale            | Kappa 3 parameter distribution.                                              |
| [ksone](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.ksone.html#scipy.stats.ksone)                                        | n, loc, scale            | Kolmogorov-Smirnov one-sided test statistic distribution.                    |
| [kstwo](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.kstwo.html#scipy.stats.kstwo)                                        | n, loc, scale            | Kolmogorov-Smirnov two-sided test statistic distribution.                    |
| [kstwobign](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.kstwobign.html#scipy.stats.kstwobign)                            | loc, scale               | Limiting distribution of scaled Kolmogorov-Smirnov two-sided test statistic. |
| [landau](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.landau.html#scipy.stats.landau)                                     | loc, scale               | A Landau continuous random variable.                                         |
| [laplace](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.laplace.html#scipy.stats.laplace)                                  | loc, scale               | A Laplace continuous random variable.                                        |
| [laplace_asymmetric](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.laplace_asymmetric.html#scipy.stats.laplace_asymmetric) | kappa, loc, scale        | An asymmetric Laplace continuous random variable.                            |
| [levy](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.levy.html#scipy.stats.levy)                                           | loc, scale               | A Levy continuous random variable.                                           |
| [levy_l](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.levy_l.html#scipy.stats.levy_l)                                     | loc, scale               | A left-skewed Levy continuous random variable.                               |
| [levy_stable](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.levy_stable.html#scipy.stats.levy_stable)                      | alpha, beta, loc, scale  | A Levy-stable continuous random variable.                                    |
| [logistic](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.logistic.html#scipy.stats.logistic)                               | loc, scale               | A logistic (or Sech-squared) continuous random variable.                     |
| [loggamma](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.loggamma.html#scipy.stats.loggamma)                               | c, loc, scale            | A log gamma continuous random variable.                                      |
| [loglaplace](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.loglaplace.html#scipy.stats.loglaplace)                         | c, loc, scale            | A log-Laplace continuous random variable.                                    |
| [lognorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.lognorm.html#scipy.stats.lognorm)                                  | s, loc, scale            | A lognormal continuous random variable.                                      |
| [loguniform](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.loguniform.html#scipy.stats.loguniform)                         | a, b, loc, scale         | A loguniform or reciprocal continuous random variable.                       |
| [lomax](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.lomax.html#scipy.stats.lomax)                                        | c, loc, scale            | A Lomax (Pareto of the second kind) continuous random variable.              |
| [maxwell](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.maxwell.html#scipy.stats.maxwell)                                  | loc, scale               | A Maxwell continuous random variable.                                        |
| [mielke](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.mielke.html#scipy.stats.mielke)                                     | k, s, loc, scale         | A Mielke Beta-Kappa / Dagum continuous random variable.                      |
| [moyal](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.moyal.html#scipy.stats.moyal)                                        | loc, scale               | A Moyal continuous random variable.                                          |
| [nakagami](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.nakagami.html#scipy.stats.nakagami)                               | nu, loc, scale           | A Nakagami continuous random variable.                                       |
| [ncx2](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.ncx2.html#scipy.stats.ncx2)                                           | df, nc, loc, scale       | A non-central chi-squared continuous random variable.                        |
| [ncf](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.ncf.html#scipy.stats.ncf)                                              | dfn, dfd, nc, loc, scale | A non-central F distribution continuous random variable.                     |
| [nct](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.nct.html#scipy.stats.nct)                                              | df, nc, loc, scale       | A non-central Student's t continuous random variable.                        |
| [norm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.norm.html#scipy.stats.norm)                                           | loc, scale               | A normal continuous random variable.                                         |
| [norminvgauss](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.norminvgauss.html#scipy.stats.norminvgauss)                   | a, b, loc, scale         | A Normal Inverse Gaussian continuous random variable.                        |
| [pareto](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.pareto.html#scipy.stats.pareto)                                     | b, loc, scale            | A Pareto continuous random variable.                                         |
| [pearson3](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.pearson3.html#scipy.stats.pearson3)                               | skew, loc, scale         | A pearson type III continuous random variable.                               |
| [powerlaw](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.powerlaw.html#scipy.stats.powerlaw)                               | a, loc, scale            | A power-function continuous random variable.                                 |
| [powerlognorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.powerlognorm.html#scipy.stats.powerlognorm)                   | c, s, loc, scale         | A power log-normal continuous random variable.                               |
| [powernorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.powernorm.html#scipy.stats.powernorm)                            | c, loc, scale            | A power normal continuous random variable.                                   |
| [rdist](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.rdist.html#scipy.stats.rdist)                                        | c, loc, scale            | An R-distributed (symmetric beta) continuous random variable.                |
| [rayleigh](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.rayleigh.html#scipy.stats.rayleigh)                               | loc, scale               | A Rayleigh continuous random variable.                                       |
| [rel_breitwigner](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.rel_breitwigner.html#scipy.stats.rel_breitwigner)          | rho, loc, scale          | A relativistic Breit-Wigner random variable.                                 |
| [rice](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.rice.html#scipy.stats.rice)                                           | b, loc, scale            | A Rice continuous random variable.                                           |
| [recipinvgauss](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.recipinvgauss.html#scipy.stats.recipinvgauss)                | mu, loc, scale           | A reciprocal inverse Gaussian continuous random variable.                    |
| [semicircular](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.semicircular.html#scipy.stats.semicircular)                   | loc, scale               | A semicircular continuous random variable.                                   |
| [skewcauchy](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.skewcauchy.html#scipy.stats.skewcauchy)                         | a, loc, scale            | A skewed Cauchy random variable.                                             |
| [skewnorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.skewnorm.html#scipy.stats.skewnorm)                               | a, loc, scale            | A skew-normal random variable.                                               |
| [studentized_range](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.studentized_range.html#scipy.stats.studentized_range)    | k, df, loc, scale        | A studentized range continuous random variable.                              |
| [t](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.t.html#scipy.stats.t)                                                    | df, loc, scale           | A Student's t continuous random variable.                                    |
| [trapezoid](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.trapezoid.html#scipy.stats.trapezoid)                            | c, d, loc, scale         | A trapezoidal continuous random variable.                                    |
| [triang](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.triang.html#scipy.stats.triang)                                     | c, loc, scale            | A triangular continuous random variable.                                     |
| [truncexpon](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.truncexpon.html#scipy.stats.truncexpon)                         | b, loc, scale            | A truncated exponential continuous random variable.                          |
| [truncnorm](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.truncnorm.html#scipy.stats.truncnorm)                            | a, b, loc, scale         | A truncated normal continuous random variable.                               |
| [truncpareto](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.truncpareto.html#scipy.stats.truncpareto)                      | b, c, loc, scale         | An upper truncated Pareto continuous random variable.                        |
| [truncweibull_min](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.truncweibull_min.html#scipy.stats.truncweibull_min)       | c, a, b, loc, scale      | A doubly truncated Weibull minimum continuous random variable.               |
| [tukeylambda](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.tukeylambda.html#scipy.stats.tukeylambda)                      | lam, loc, scale          | A Tukey-Lamdba continuous random variable.                                   |
| [uniform](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.uniform.html#scipy.stats.uniform)                                  | loc, scale               | A uniform continuous random variable.                                        |
| [vonmises](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.vonmises.html#scipy.stats.vonmises)                               | kappa, loc               | A Von Mises continuous random variable.                                      |
| [vonmises_line](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.vonmises_line.html#scipy.stats.vonmises_line)                | kappa, loc               | A Von Mises continuous random variable.                                      |
| [wald](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.wald.html#scipy.stats.wald)                                           | loc, scale               | A Wald continuous random variable.                                           |
| [weibull_min](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.weibull_min.html#scipy.stats.weibull_min)                      | c, loc, scale            | Weibull minimum continuous random variable.                                  |
| [weibull_max](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.weibull_max.html#scipy.stats.weibull_max)                      | c, loc, scale            | Weibull maximum continuous random variable.                                  |
| [wrapcauchy](https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.wrapcauchy.html#scipy.stats.wrapcauchy)                         | c, loc, scale            | A wrapped Cauchy continuous random variable.                                 |
